
exports.up = function (knex, Promise) {
    return knex.schema.createTable('messages_answers', function (table) {
        table.integer('mid').primary().notNullable() //(non-nullable) primary key
            .references('mid').inTable('messages')
            .onDelete('CASCADE'); 
        table.timestamps(true, true); //adds timestamptz-type (a PostgresQL data type) updated_at and created_at columns

        table.string('title').notNullable();
        table.text('content').notNullable();

        table.string('userAuthor')
            .references('uid').inTable('users')
            .onDelete('SET NULL');
        
        /*
        we require that a GraphQL Answer's author field be the same as its recipient field.
        since recipient is already known (defined in the 'messages' parent-table),
        then we simply don't store answers' authors in database.
        (another way would be to add equality constraints, but uselessly complex.)
        table.string('author', 128).notNullable()
            .references('gid').inTable('groups')
            .onDelete('CASCADE');
        */

        table.integer('for_question').notNullable()
            .references('mid').inTable('messages_questions')
            .onDelete('CASCADE'); //if question is deleted, also delete the answer

    }).table('messages_questions', function (table) { //update 'questions' table by adding the 'for_answer' column
        table.integer('for_answer')
            .references('mid').inTable('messages_answers')
            .onDelete('SET NULL'); //if answer is deleted, set for_answer to null
    });
};

exports.down = function (knex, Promise) {
    return knex.schema.table('messages_questions', function (table) {
        table.dropColumn('for_answer');
    }).dropTable('messages_answers');
};
